@@ -6,10 +6,11 @@
 #         game-id | Game name
 games_list_supported() {
 	local archives_list
-	archives_list=$(archives_return_list)
+	archives_list=$(archives_list)
 
 	local archive game_id game_name
 	for archive in $archives_list; do
+		# Using a subshell to prevent the context archive setting from leaking outside of this function is not required
 		set_current_archive "$archive"
 		game_id=$(game_id)
 		game_name=$(game_name)
