@@ -160,7 +160,10 @@ content_inclusion_default_fonts() {
 	fi
 
 	local target_directory
-	target_directory=$(path_fonts_ttf)
+	target_directory=$(
+		set_current_package "$package"
+		path_fonts_ttf
+	)
 	content_inclusion "FONTS_${package_suffix}" "$package" "$target_directory"
 	local index
 	for index in $(seq 0 9); do
@@ -184,8 +187,6 @@ content_inclusion_default_game_data() {
 	package_suffix="${package#PKG_}"
 	files_list=$(context_name "CONTENT_GAME_${package_suffix}_FILES")
 	if [ -z "$files_list" ]; then
-		## Try to parse legacy variables for old game scripts.
-		content_inclusion_default_game_data_legacy "$package"
 		## Check if a default files list is set for the current engine,
 		## return early otherwise.
 		local content_files
@@ -196,7 +197,10 @@ content_inclusion_default_game_data() {
 	fi
 
 	local target_directory
-	target_directory=$(path_game_data)
+	target_directory=$(
+		set_current_package "$package"
+		path_game_data
+	)
 	content_inclusion "GAME_${package_suffix}" "$package" "$target_directory"
 	local index
 	for index in $(seq 0 9); do
@@ -221,8 +225,6 @@ content_inclusion_default_documentation() {
 	package_suffix="${package#PKG_}"
 	files_list=$(context_name "CONTENT_DOC_${package_suffix}_FILES")
 	if [ -z "$files_list" ]; then
-		## Try to parse legacy variables for old game scripts.
-		content_inclusion_default_game_documentation_legacy "$package"
 		## Check if a default files list is set for the current engine,
 		## return early otherwise.
 		local content_files
@@ -233,7 +235,10 @@ content_inclusion_default_documentation() {
 	fi
 
 	local target_directory
-	target_directory=$(path_documentation)
+	target_directory=$(
+		set_current_package "$package"
+		path_documentation
+	)
 	content_inclusion "DOC_${package_suffix}" "$package" "$target_directory"
 	local index
 	for index in $(seq 0 9); do
@@ -317,10 +322,10 @@ content_inclusion_find_options() {
 			continue
 		fi
 		if [ $first_path_shown -eq 0 ]; then
-			printf_format='-path\0./%s'
+			printf_format='-ipath\0./%s'
 			first_path_shown=1
 		else
-			printf_format='\0-o\0-path\0./%s'
+			printf_format='\0-o\0-ipath\0./%s'
 		fi
 		## Silence ShellCheck false-positive
 		## Don't use variables in the printf format string. Use printf "..%s.." "$foo".
