@@ -75,9 +75,9 @@ dependencies_unknown_command_add() {
 	unknown_commands_list=$(dependencies_unknown_commands_file)
 
 	# Do nothing if this command is already included in the list
-	if \
-		[ -e "$unknown_commands_list" ] \
-		&& grep --quiet --fixed-strings --word-regexp "$unknown_command" "$unknown_commands_list"
+	if
+		[ -e "$unknown_commands_list" ] &&
+		grep --quiet --fixed-strings --word-regexp "$unknown_command" "$unknown_commands_list"
 	then
 		return 0
 	fi
