@@ -13,7 +13,10 @@ hacks_inclusion_default() {
 		fi
 		for hack in $hacks_list; do
 			hack_build "$hack"
-			hack_inclusion "$hack"
+			(
+				set_current_package "$package"
+				hack_inclusion "$hack"
+			)
 		done
 	done
 }
