@@ -4,12 +4,6 @@
 # RETURN: the pre-run actions, can span over multiple lines,
 #         or an empty string if there are none
 dosbox_prerun() {
-	# Game scripts targeting ./play.it < 2.20 used to set these actions through APP_xxx_PRERUN.
-	if ! compatibility_level_is_at_least '2.20'; then
-		dosbox_prerun_legacy "$application"
-		return 0
-	fi
-
 	local application
 	application="$1"
 
@@ -22,12 +16,6 @@ dosbox_prerun() {
 # RETURN: the post-run actions, can span over multiple lines,
 #         or an empty string if there are none
 dosbox_postrun() {
-	# Game scripts targeting ./play.it < 2.20 used to set these actions through APP_xxx_PRERUN.
-	if ! compatibility_level_is_at_least '2.20'; then
-		dosbox_postrun_legacy "$application"
-		return 0
-	fi
-
 	local application
 	application="$1"
 
