@@ -9,10 +9,14 @@ native_launcher() {
 	case "$prefix_type" in
 		('symlinks')
 			launcher_headers
+
+			# Set the paths that should be available to the generated launcher
+			launcher_init_paths "$application"
+
 			native_launcher_environment "$application"
 
 			# Generate the game prefix
-			launcher_prefix_symlinks_functions
+			prefix_generate_links_farm
 			launcher_prefix_symlinks_build
 
 			# Set up the paths diversion to persistent storage
@@ -36,6 +40,10 @@ native_launcher() {
 		;;
 		('none')
 			launcher_headers
+
+			# Set the paths that should be available to the generated launcher
+			launcher_init_paths "$application"
+
 			native_launcher_environment "$application"
 			native_launcher_run "$application"
 			launcher_exit
@@ -53,16 +61,12 @@ native_launcher_environment() {
 	local application
 	application="$1"
 
-	local game_id path_game application_exe
-	game_id=$(game_id)
-	path_game=$(path_game_data)
+	local application_exe
 	application_exe=$(application_exe_escaped "$application")
 
 	cat <<- EOF
 	# Set the environment
 
-	GAME_ID='$game_id'
-	PATH_GAME='$path_game'
 	APP_EXE='$application_exe'
 
 	EOF
@@ -81,7 +85,7 @@ native_launcher_run() {
 			execution_path='$PATH_PREFIX'
 		;;
 		('none')
-			execution_path='$PATH_GAME'
+			execution_path='$PATH_GAME_DATA'
 		;;
 	esac
 	cat <<- EOF
@@ -91,12 +95,6 @@ native_launcher_run() {
 
 	EOF
 
-	# Set loading paths for libraries
-	## This must be called before the engine specific tweaks, so they have access to the following variables:
-	## - PLAYIT_LIBS_PATH_SYSTEM
-	## - PLAYIT_LIBS_PATH_USER
-	native_launcher_libraries
-
 	local game_engine
 	game_engine=$(game_engine)
 	case "$game_engine" in
@@ -156,6 +154,13 @@ native_launcher_run() {
 		fake_home_enable
 	fi
 
+	# Set the preload paths for native libraries
+	cat <<- 'EOF'
+	## Set the preload paths for native libraries
+	export LD_LIBRARY_PATH="${PATH_LIBRARIES_USER}:${PATH_LIBRARIES_SYSTEM}:${LD_LIBRARY_PATH:-}"
+
+	EOF
+
 	application_prerun "$application"
 
 	cat <<- 'EOF'
@@ -204,30 +209,6 @@ native_launcher_binary_copy() {
 	EOF
 }
 
-# Linux native launcher - Load shipped libraries
-# USAGE: native_launcher_libraries
-native_launcher_libraries() {
-	local path_system path_user
-	path_system=$(path_libraries)
-	path_user='${HOME}/.local/lib/games/${GAME_ID}'
-
-	cat <<- EOF
-	# Set loading paths for libraries
-	PLAYIT_LIBS_PATH_SYSTEM='$path_system'
-	PLAYIT_LIBS_PATH_USER="$path_user"
-	EOF
-	cat <<- 'EOF'
-	if [ -e "$PLAYIT_LIBS_PATH_SYSTEM" ]; then
-	    LD_LIBRARY_PATH="${PLAYIT_LIBS_PATH_SYSTEM}:${LD_LIBRARY_PATH}"
-	fi
-	if [ -e "$PLAYIT_LIBS_PATH_USER" ]; then
-	    LD_LIBRARY_PATH="${PLAYIT_LIBS_PATH_USER}:${LD_LIBRARY_PATH}"
-	fi
-	export LD_LIBRARY_PATH
-
-	EOF
-}
-
 # Linux native - Print the line starting the game
 # USAGE: native_exec_line $application
 # RETURN: the command to execute, including its command line options
