@@ -199,14 +199,5 @@ wine_launcher_wineprefix_persistent() {
 		EOF
 		return 0
 	fi
-
-	# Handle diversions using the deprecated APP_WINE_LINK_DIRS variable,
-	# for game scripts targeting ./play.it < 2.24.
-	if compatibility_level_is_at_least '2.24'; then
-		return 0
-	fi
-	if [ -n "${APP_WINE_LINK_DIRS:-}" ]; then
-		wine_launcher_wineprefix_persistent_legacy
-	fi
 }
 
