@@ -34,6 +34,10 @@ unity3d_version_file() {
 	packages_list=$(packages_list)
 	for package in $packages_list; do
 		package_path=$(package_path "$package")
+		path_game_data=$(
+			set_current_package "$package"
+			path_game_data
+		)
 		engine_info_file_path="${package_path}${path_game_data}/${engine_info_file}"
 		if [ -f "$engine_info_file_path" ]; then
 			printf '%s' "$engine_info_file_path"
