@@ -35,11 +35,11 @@ launcher_unity3d_pulseaudio_hide_libpulse() {
 	cat <<- 'EOF'
 	# Work around crash on launch related to libpulse
 	# Some Unity3D games crash on launch if libpulse-simple.so.0 is available but pulseaudio is not running
-	libpulse_null_link="${PLAYIT_LIBS_PATH_USER}/libpulse-simple.so.0"
+	libpulse_null_link="${PATH_LIBRARIES_USER}/libpulse-simple.so.0"
 	if pulseaudio_is_available; then
 	    rm --force "$libpulse_null_link"
 	else
-	    mkdir --parents "$PLAYIT_LIBS_PATH_USER"
+	    mkdir --parents "$PATH_LIBRARIES_USER"
 	    ln --force --symbolic /dev/null "$libpulse_null_link"
 	fi
 	unset libpulse_null_link
