@@ -96,6 +96,10 @@ archlinux_dependencies_single_command() {
 			package_names='
 			xorg-setxkbmap'
 		;;
+		('terminal_wrapper')
+			package_names='
+			xterm'
+		;;
 		('vcmilauncher')
 			package_names='
 			vcmi'
@@ -106,8 +110,7 @@ archlinux_dependencies_single_command() {
 		;;
 		('winetricks')
 			package_names='
-			winetricks
-			xterm'
+			winetricks'
 		;;
 		('xgamma')
 			package_names='
