@@ -53,6 +53,22 @@ debian_dependencies_single_command() {
 			package_names='
 			dosbox'
 		;;
+		('dxvk-setup | winetricks')
+			local package_architecture
+			package_architecture=$(package_architecture "$package")
+			case "$package_architecture" in
+				('64')
+					package_names='
+					dxvk-wine64 | winetricks
+					dxvk | winetricks'
+				;;
+				('32')
+					package_names='
+					dxvk-wine32 | winetricks
+					dxvk | winetricks'
+				;;
+			esac
+		;;
 		('godot3-runner')
 			package_names='
 			godot3-runner'
@@ -97,6 +113,20 @@ debian_dependencies_single_command() {
 			package_names='
 			x11-xkb-utils'
 		;;
+		('terminal_wrapper')
+			local package_architecture
+			package_architecture=$(package_architecture "$package")
+			case "$package_architecture" in
+				('32')
+					package_names='
+					xterm:amd64 | xterm | x-terminal-emulator:amd64 | x-terminal-emulator'
+				;;
+				('64')
+					package_names='
+					xterm | x-terminal-emulator'
+				;;
+			esac
+		;;
 		('vcmilauncher')
 			package_names='
 			vcmi'
@@ -118,8 +148,7 @@ debian_dependencies_single_command() {
 		;;
 		('winetricks')
 			package_names='
-			winetricks
-			xterm:amd64 | xterm | zenity:amd64 | zenity | kdialog:amd64 | kdialog'
+			winetricks'
 		;;
 		('xgamma')
 			package_names='
