@@ -4,8 +4,9 @@ warning_debian_size_limit() {
 	local package
 	package="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Le paquet suivant est trop gros pour le format .deb moderne : %s\n'
 			message="$message"'Merci de signaler cet avertissement sur notre système de suivi : %s\n\n'
