@@ -98,6 +98,10 @@ gentoo_dependencies_single_command() {
 			package_names='
 			x11-apps/setxkbmap'
 		;;
+		('terminal_wrapper')
+			package_names='
+			x11-terms/xterm'
+		;;
 		('vcmilauncher')
 			dependency_gentoo_overlays_add 'https://cgit.gentoo.org/proj/gamerlay.git'
 			package_names='
@@ -118,11 +122,6 @@ gentoo_dependencies_single_command() {
 			esac
 		;;
 		('winetricks')
-			## TODO - Add an OR dependency on one of these packages:
-			## - x11-terms/xterm
-			## - gnome-extra/zenity
-			## - kde-apps/kdialog
-			## This dependency must be set on a single line.
 			package_names='
 			app-emulation/winetricks'
 		;;
