@@ -5,11 +5,6 @@ warning_deprecated_function() {
 	old_function="$1"
 	new_function="$2"
 
-	# Skip this warning if it has already been shown.
-	if deprecation_warning_has_been_shown_already "warning_deprecated_function $*"; then
-		return 0
-	fi
-
 	local messages_language message
 	messages_language=$(messages_language)
 	case "$messages_language" in
@@ -25,13 +20,10 @@ warning_deprecated_function() {
 
 	# Print the message on the standard error output,
 	# to avoid messing up the regular output of the function that triggered this warning.
-	print_message 'warning' "$message" \
+	print_message 'warning_once' "$message" \
 		"$old_function" \
 		"$new_function" \
 		> /dev/stderr
-
-	# Prevent this warning from being shown again.
-	deprecation_warnings_shown_add "warning_deprecated_function $*"
 }
 
 # Warning: A deprecated variable is set.
@@ -41,11 +33,6 @@ warning_deprecated_variable() {
 	old_variable="$1"
 	new_variable="$2"
 
-	# Skip this warning if it has already been shown.
-	if deprecation_warning_has_been_shown_already "warning_deprecated_variable $*"; then
-		return 0
-	fi
-
 	local messages_language message
 	messages_language=$(messages_language)
 	case "$messages_language" in
@@ -61,13 +48,10 @@ warning_deprecated_variable() {
 
 	# Print the message on the standard error output,
 	# to avoid messing up the regular output of the variable that triggered this warning.
-	print_message 'warning' "$message" \
+	print_message 'warning_once' "$message" \
 		"$old_variable" \
 		"$new_variable" \
 		> /dev/stderr
-
-	# Prevent this warning from being shown again.
-	deprecation_warnings_shown_add "warning_deprecated_variable $*"
 }
 
 # Warning: An option is set to a deprecated value.
@@ -77,11 +61,6 @@ warning_option_value_deprecated() {
 	option_name="$1"
 	option_value="$2"
 
-	# Skip this warning if it has already been shown.
-	if deprecation_warning_has_been_shown_already "warning_option_value_deprecated $*"; then
-		return 0
-	fi
-
 	local messages_language message
 	messages_language=$(messages_language)
 	case "$messages_language" in
@@ -95,13 +74,10 @@ warning_option_value_deprecated() {
 
 	# Print the message on the standard error output,
 	# to avoid messing up the regular output of the variable that triggered this warning.
-	print_message 'warning' "$message" \
+	print_message 'warning_once' "$message" \
 		"$option_name" \
 		"$option_value" \
 		> /dev/stderr
-
-	# Prevent this warning from being shown again.
-	deprecation_warnings_shown_add "warning_option_value_deprecated $*"
 }
 
 # Warning: An archive has a deprecated type set.
@@ -110,11 +86,6 @@ warning_archive_type_deprecated() {
 	local archive
 	archive="$1"
 
-	# Skip this warning if it has already been shown.
-	if deprecation_warning_has_been_shown_already "warning_archive_type_deprecated $*"; then
-		return 0
-	fi
-
 	local archive_type game_name
 	archive_type=$(archive_type "$archive")
 	game_name=$(game_name)
@@ -132,23 +103,15 @@ warning_archive_type_deprecated() {
 
 	# Print the message on the standard error output,
 	# to avoid messing up the regular output of the variable that triggered this warning.
-	print_message 'warning' "$message" \
+	print_message 'warning_once' "$message" \
 		"$game_name" \
 		"$archive_type" \
 		> /dev/stderr
-
-	# Prevent this warning from being shown again.
-	deprecation_warnings_shown_add "warning_archive_type_deprecated $*"
 }
 
 # Warning - The legacy variable has been use to set the current archive.
 # USAGE: warning_context_legacy_archive
 warning_context_legacy_archive() {
-	# Skip this warning if it has already been shown.
-	if deprecation_warning_has_been_shown_already 'warning_context_legacy_archive'; then
-		return 0
-	fi
-
 	local messages_language message
 	messages_language=$(messages_language)
 	case "$messages_language" in
@@ -164,20 +127,12 @@ warning_context_legacy_archive() {
 
 	# Print the message on the standard error output,
 	# to avoid messing up the regular output of the function that triggered this warning.
-	print_message 'warning' "$message" > /dev/stderr
-
-	# Prevent this warning from being shown again.
-	deprecation_warnings_shown_add 'warning_context_legacy_archive'
+	print_message 'warning_once' "$message" > /dev/stderr
 }
 
 # Warning - The legacy variable has been use to set the current package.
 # USAGE: warning_context_legacy_package
 warning_context_legacy_package() {
-	# Skip this warning if it has already been shown.
-	if deprecation_warning_has_been_shown_already 'warning_context_legacy_package'; then
-		return 0
-	fi
-
 	local messages_language message
 	messages_language=$(messages_language)
 	case "$messages_language" in
@@ -193,9 +148,6 @@ warning_context_legacy_package() {
 
 	# Print the message on the standard error output,
 	# to avoid messing up the regular output of the function that triggered this warning.
-	print_message 'warning' "$message" > /dev/stderr
-
-	# Prevent this warning from being shown again.
-	deprecation_warnings_shown_add 'warning_context_legacy_package'
+	print_message 'warning_once' "$message" > /dev/stderr
 }
 
